@@ -24,7 +24,7 @@
 #define INCLUDED_GR_UDP_SINK_H
 
 #include <gr_sync_block.h>
-#include <omnithread.h>
+#include <gnuradio/omnithread.h>
 #if defined(HAVE_SOCKET)
 #include <sys/socket.h>
 #include <arpa/inet.h>
@@ -47,7 +47,7 @@ gr_make_udp_sink (size_t itemsize,
 
 /*!
  * \brief Write stream to an UDP socket.
- * \ingroup sink
+ * \ingroup sink_blk
  * 
  * \param itemsize     The size (in bytes) of the item datatype
  * \param src          The source address as either the host name or the 'numbers-and-dots'
