@@ -24,7 +24,7 @@
 #define INCLUDED_GR_UDP_SOURCE_H
 
 #include <gr_sync_block.h>
-#include <omnithread.h>
+#include <gnuradio/omnithread.h>
 #if defined(HAVE_SOCKET)
 #include <sys/socket.h>
 #include <arpa/inet.h>
@@ -44,7 +44,7 @@ gr_udp_source_sptr gr_make_udp_source(size_t itemsize, const char *src,
 
 /*! 
  * \brief Read stream from an UDP socket.
- * \ingroup sink
+ * \ingroup source_blk
  *
  * \param itemsize     The size (in bytes) of the item datatype
  * \param src          The source address as either the host name or the 'numbers-and-dots'
