@@ -25,7 +25,6 @@
 #endif
 #include <qa_gr_block.h>
 #include <gr_block.h>
-#include <gr_runtime.h>
 #include <gr_io_signature.h>
 #include <gr_null_sink.h>
 #include <gr_null_source.h>
@@ -43,7 +42,7 @@ qa_gr_block::t0 ()
   CPPUNIT_ASSERT_EQUAL (0, src1->input_signature()->max_streams ());
   CPPUNIT_ASSERT_EQUAL (1, src1->output_signature()->min_streams ());
   CPPUNIT_ASSERT_EQUAL (1, src1->output_signature()->max_streams ());
-  CPPUNIT_ASSERT_EQUAL (sizeof (int),
+  CPPUNIT_ASSERT_EQUAL ((int) sizeof(int),
 			src1->output_signature()->sizeof_stream_item (0));
 
   gr_block_sptr src2 (gr_make_null_source (sizeof (short)));
@@ -51,7 +50,7 @@ qa_gr_block::t0 ()
   CPPUNIT_ASSERT_EQUAL (0, src2->input_signature()->max_streams ());
   CPPUNIT_ASSERT_EQUAL (1, src2->output_signature()->min_streams ());
   CPPUNIT_ASSERT_EQUAL (1, src2->output_signature()->max_streams ());
-  CPPUNIT_ASSERT_EQUAL (sizeof (short),
+  CPPUNIT_ASSERT_EQUAL ((int) sizeof (short),
 			src2->output_signature()->sizeof_stream_item (0));
 }
 
@@ -64,7 +63,7 @@ qa_gr_block::t1 ()
   CPPUNIT_ASSERT_EQUAL (std::string ("null_sink"), dst1->name ());
   CPPUNIT_ASSERT_EQUAL (1, dst1->input_signature()->min_streams ());
   CPPUNIT_ASSERT_EQUAL (1, dst1->input_signature()->max_streams ());
-  CPPUNIT_ASSERT_EQUAL (sizeof (int),
+  CPPUNIT_ASSERT_EQUAL ((int) sizeof (int),
 			dst1->input_signature()->sizeof_stream_item (0));
 
   CPPUNIT_ASSERT_EQUAL (0, dst1->output_signature()->max_streams ());
@@ -73,7 +72,7 @@ qa_gr_block::t1 ()
   CPPUNIT_ASSERT_EQUAL (std::string ("null_sink"), dst2->name ());
   CPPUNIT_ASSERT_EQUAL (1, dst2->input_signature()->min_streams ());
   CPPUNIT_ASSERT_EQUAL (1, dst2->input_signature()->max_streams ());
-  CPPUNIT_ASSERT_EQUAL (sizeof (short),
+  CPPUNIT_ASSERT_EQUAL ((int) sizeof (short),
 			dst2->input_signature()->sizeof_stream_item (0));
   CPPUNIT_ASSERT_EQUAL (0, dst2->output_signature()->max_streams ());
 }
