@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 #
-# Copyright 2004 Free Software Foundation, Inc.
+# Copyright 2004,2007 Free Software Foundation, Inc.
 # 
 # This file is part of GNU Radio
 # 
@@ -26,10 +26,10 @@ import math
 class test_interp_fir_filter (gr_unittest.TestCase):
 
     def setUp (self):
-        self.fg = gr.flow_graph ()
+        self.tb = gr.top_block ()
 
     def tearDown (self):
-        self.fg = None
+        self.tb = None
 
     def test_fff (self):
         taps = [1, 10, 100, 1000, 10000]
@@ -41,9 +41,9 @@ class test_interp_fir_filter (gr_unittest.TestCase):
         src = gr.vector_source_f (src_data)
         op = gr.interp_fir_filter_fff (interpolation, taps)
         dst = gr.vector_sink_f ()
-        self.fg.connect (src, op)
-        self.fg.connect (op, dst)
-        self.fg.run ()
+        self.tb.connect (src, op)
+        self.tb.connect (op, dst)
+        self.tb.run ()
         result_data = dst.data ()
         L = min(len(result_data), len(expected_result))
         self.assertEqual (expected_result[0:L], result_data[0:L])
