@@ -24,7 +24,7 @@
 
 #include <gr_sync_block.h>
 #include <gr_buffer.h>
-#include <omnithread.h>
+#include <gnuradio/omnithread.h>
 #include <string>
 #include <portaudio.h>
 #include <stdexcept>
@@ -34,14 +34,15 @@ class audio_portaudio_sink;
 typedef boost::shared_ptr<audio_portaudio_sink> audio_portaudio_sink_sptr;
 
 /*!
- * \PORTAUDIO audio sink.
+ * \brief PORTAUDIO audio sink.
+ *
  * \param sampling_rate	sampling rate in Hz
- * \param dev PORTAUDIO device name, e.g., "pa:"
+ * \param device_name PORTAUDIO device name, e.g., "pa:"
  * \param ok_to_block	true if it's ok for us to block
  */
 audio_portaudio_sink_sptr
 audio_portaudio_make_sink (int sampling_rate,
-			   const std::string dev = "",
+			   const std::string device_name = "",
 			   bool ok_to_block = true);
 
 PaStreamCallback portaudio_sink_callback;
